==> KPopUp.0.1.4.tgz: KPopUp/menu.cpp <==
/*
  #############################################################################
  # Diese Datei gehrt zu:                                                    #
  #                                                                           #
  #                  KPOPUP V 0.1.4           (C) Gernot Stocker              #
  #                  ==============                                           #
  #                                                                           #
  #############################################################################
*/
#include <stdio.h>
#include <iostream.h>
#include <string.h>
#include <qstring.h>
#include <stdlib.h>
#include <stdio.h>
#include <kapp.h>
#include <qpushbt.h>
#include <qfont.h>
#include <qlabel.h>
#include <malloc.h>
#include <qtooltip.h>
#include <qlined.h>
#include <qcombo.h>
#include <qfile.h>
#include <qwidget.h>
#include <qdialog.h>
#include <qmlined.h>
#include <qmsgbox.h>
#include <klocale.h>
#include <qdatetm.h>
#include "menu.h"


//
// Definitionen
//

QApplication *a;


char *Datei_Lesen(const char *DName, int ZLaenge)
    {
      char *PUText=0;

      FILE *Datei;
      int i=0, linel=0;

      if ( (Datei=fopen(DName,"r")) != 0)
      { 
        while ( !feof(Datei) )
         { 
	  if (PUText == 0) PUText = (char *)malloc (sizeof(char));
	  else PUText = (char *)realloc (PUText, sizeof(char)*i +1);
	  PUText[i]=fgetc(Datei);
          if (PUText[i]=='\n') linel=0; else linel++;
	  if (linel==ZLaenge)
             {
	      PUText = (char *)realloc (PUText, sizeof(char)*i +1);	      
	      PUText[++i]='\n';
	      linel=0;
             };
	  i++;
         } 
        PUText[i-1]=' ';
        if (PUText == 0) PUText = (char *)malloc (sizeof(char));
        else PUText = (char *)realloc (PUText, sizeof(char)*i +1);
        PUText[i]='\0';
        fclose(Datei);

        char befehl[50];
        sprintf(befehl,"rm -f %s",DName);
        system(befehl);
      }    
      else
      { 
         printf("Dateifehler!\n");
      };
      return PUText;
 }




//
// Klassen und ihre Definitionen
//

MyWidget::MyWidget( int pzahl, char **param, QWidget *parent=0, const char *name=0 )
        : QWidget( parent, name)
{
   
      if (pzahl==4)
       { 
        DateiName = (char *)malloc(((strlen(param[1])+1)*(sizeof(char))));
        sprintf(DateiName,param[1]);
        DateiName[strlen(param[1])]=0;

        Absender  = (char *)malloc(((strlen(param[2])+1)*(sizeof(char))));
        sprintf(Absender,param[2]);
        Absender[strlen(param[2])]=0;
  
        Empfaenger   = (char *)malloc(((strlen(param[3])+1)*(sizeof(char))));
        sprintf(Empfaenger,param[3]);
        Empfaenger[strlen(param[3])]=0;
       }
      else
       {
        DateiName = (char *)malloc(1*(sizeof(char)));
        DateiName[0]=0;
        Absender  = (char *)malloc(1*(sizeof(char)));
        Absender[0]=0;
        Empfaenger = (char *)malloc(1*(sizeof(char))); 
        Empfaenger[0]=0;
       };
      setMinimumSize( 290, 270 );
      setMaximumSize( 290, 270);
    
      quit = new QPushButton( klocale->translate("Beenden"), this, "quit" );
      quit->setGeometry( 20, 10, 75, 30 );
      connect( quit, SIGNAL(clicked()), qApp, SLOT(quit()) );

      Return = new QPushButton( klocale->translate( "Antworten"), this, "antworten" );
      Return->setGeometry( 107, 10, 75, 30 );
      connect( Return, SIGNAL( clicked() ), this, SLOT( answer() ) );

      NeuPU = new QPushButton( klocale->translate( "Neues PU"), this, "neues PU" );
      NeuPU->setGeometry( 194, 10, 75, 30 );
      connect( NeuPU, SIGNAL(clicked()), this, SLOT( neuespu() ) );

      Kom_Header = new QLabel(klocale->translate( "Nachricht von: "),this);
      Kom_Header->setGeometry(22,53,98,20);
      Kom_Header->setAlignment( AlignTop | AlignLeft );

      Header = new QLabel(Absender,this);
      Header->setGeometry(120, 50,150,20);
      Header->setFrameStyle( QFrame::Panel | QFrame::Sunken );
      Header->setAlignment( AlignTop | AlignLeft );

      Kom_Empf =   new QLabel(klocale->translate( "an: "),this);
      Kom_Empf->setGeometry(60,78,98,20);
      Kom_Empf->setAlignment( AlignTop | AlignLeft );

      Empf = new QLabel(Empfaenger,this);
      Empf->setGeometry(120, 75, 150,20);
      Empf->setFrameStyle( QFrame::Panel | QFrame::Sunken );
      Empf->setAlignment( AlignTop | AlignLeft );

      Uhrzeit = new QTime();
      *Uhrzeit = Uhrzeit->currentTime();

/*      QLabel *Kom_Uhr;
      Kom_Uhr =   new QLabel(klocale->translate( "um: "),this);
      Kom_Uhr->setGeometry(60,103,98,20);
      Kom_Uhr->setAlignment( AlignTop | AlignLeft );

      QLabel *Uhr;
      Uhr = new QLabel(Uhrzeit->toString() ,this);
      Uhr->setGeometry(120, 100, 150,20);
      Uhr->setFrameStyle( QFrame::Panel | QFrame::Sunken );
      Uhr->setAlignment( AlignTop | AlignLeft );
*/
      PUText = new QMultiLineEdit(this,"TEXT");
      if (strlen(DateiName)!=0)
        {
           PUText->setText("Erhalten um: "+ Uhrzeit->toString()+
                           "\n------------------------------\n"+
                           Datei_Lesen( DateiName ,41));
        }
        else
        {
           PUText->setText("");      
        };
      PUText->setReadOnly(TRUE);
      PUText->setGeometry(20,103,250,150);
      PUText->setFrameStyle( QFrame::Panel | QFrame::Sunken );
}

void MyWidget::answer()
{
  Antwort *ant;
  ant = new Antwort (this, "Blabla");
  ant->resize( 280, 220 );
  ant->setCaption( klocale->translate( "Antworten!") );
  if (strlen(Absender)==0) 
      {
      ant->empf->insertItem(" localhost",-1);
      }
      else
      {
      ant->empf->insertItem(Absender,-1);
      };
  ant->readbrowselist();
  ant->exec();
}

void MyWidget::neuespu()
{
  Antwort *ant;
  ant = new Antwort (this, "Blabla");
  ant->resize( 280, 220 );
  ant->empf->insertItem(klocale->translate( " localhost"),-1);
  ant->readbrowselist();
  ant->setCaption( klocale->translate("Neues PopUP!") );
  ant->empf->setCurrentItem(0);
  ant->exec();
}


Antwort::Antwort( QWidget *parent, const char *name )
        : QDialog( parent, name, TRUE )
{
     ok = new QPushButton( klocale->translate("OK"), this );
     ok->setGeometry( 25, 190, 60, 25 );
     connect( ok, SIGNAL(clicked()), SLOT(schicken()));

     cancel = new QPushButton( klocale->translate("Abbrechen"), this );
     cancel->setGeometry( 180, 190, 75,25 );
     connect( cancel, SIGNAL(clicked()), SLOT(reject()) );

     kom_user = new QLabel(klocale->translate("Von: "),this);
     kom_user->setGeometry(20,9,30,20);
     user = new QLineEdit( this, "read-write combo" );
     user->setGeometry(55,8,205,22);
     readhostname();
     user->setMaxLength(25);

     kom_empf = new QLabel(klocale->translate( "An: "),this);
     kom_empf->setGeometry(20,34,30,20);
     empf = new QComboBox( TRUE, this, "read-write combo" );
     empf->setGeometry(55,34,205,26);

     kom_ptext = new QLabel(klocale->translate("Text: "),this);
     kom_ptext->setGeometry(20,61,98,20);
     ptext = new QMultiLineEdit(this);
     ptext->setGeometry(20,85,240,100);

}


void Antwort::schicken()
{
   FILE *Datei;
   char befehlszeile[182];
   int count=0;
   sprintf(befehlszeile,"%s/smbclient -M %s -U %s >/dev/null",SMBPFAD,empf->currentText(),user->text());
   if ((Datei=popen(befehlszeile,"w"))!=0)
  {
   while (count < ptext->numLines())  
    { 
     fprintf(Datei,"%s\n",ptext->textLine(count)); 
     count++; 
    }
    if (pclose(Datei)==0)
           { 
             QMessageBox *Super;
             Super = new QMessageBox();
             Super->information(this,"                      :-))    " ,klocale->translate("Erfolgreich gesendet!"));  
             reject();
              };
   };
    QMessageBox *Fehler;
    Fehler = new QMessageBox();
    Fehler->information(this,klocale->translate("                        FEHLER") ,klocale->translate("Fehler bei Schicken!"));  
}


void Antwort::readbrowselist()
{
    QFile *Datei;
    char *Zeile;
    int flag1=0,flag2=0;
    Zeile = (char *)malloc(201*(sizeof(char)));
    Datei = new QFile("/tmp/browse.pup");

    if (Datei->open( IO_ReadOnly ))
    {
      while (!(Datei->atEnd()))
      {
        Datei->readLine(Zeile,200);
        if ((strlen(Zeile)==1)&&(flag1==1)) flag2=1;

        if ((flag1==1)&&(flag2==0))
          {
           if ((strlen(Zeile) >22)&&(Zeile[0]=='\t')&&(strncmp(Zeile,"	---",4)==1))
            {
             Zeile[0]=' ';
             Zeile[22]=0;
             empf->insertItem(Zeile,-1);
            };
           };
        if ((strncmp(Zeile,"	Server               Comment",24))==0) flag1=1;

       }
      free(Zeile);
      Datei->close();
    };
}

void Antwort::readhostname()
{
    FILE *Datei;
    char Zeile[201], *Zeighin;
 
    sprintf(Zeile,"%s/hostname",HOSTNAMEPFAD);
 
    if ((Datei=popen(Zeile,"r"))!=0)
      { Zeile[0]='\0';   
        fgets(Zeile,200,Datei); 
        pclose(Datei);
        Zeighin=strpbrk(Zeile,"\n\r");
        *Zeighin='\0';
        if (strlen(Zeile))
             {
              user->setText(Zeile);
              return;
             };
      };
    user->setText(" localhost");
}

int main( int argc, char **argv )
{
    KApplication a( argc, argv );
    MyWidget w(argc, argv);
    w.setGeometry( 100, 100, 400, 400 );
    a.setMainWidget( &w );
    if (argc!=1) {a.beep();};
    w.setCaption( "   KPopUP !     (c) muecketb" );
    w.show();
    return a.exec();
}

==> KPopUp.v1.1b.tgz: KPopUp/menu.cpp <==
/*
  #############################################################################
  # Diese Datei gehrt zu:                                                    #
  #                                                                           #
  #                  KPOPUP V 1.1B            (C) Gernot Stocker              #
  #                  =============                                            #
  #                                                                           #
  #############################################################################
*/

#include <stdio.h>
#include <iostream.h>
#include <string.h>
#include <qstring.h>
#include <stdlib.h>
#include <stdio.h>
#include <kapp.h>
#include <qpushbt.h>
#include <qfont.h>
#include <qlabel.h>
#include <malloc.h>
#include <qtooltip.h>
#include <qlined.h>
#include <qcombo.h>
#include <qfile.h>
#include <qwidget.h>
#include <qdialog.h>
#include <qmlined.h>
#include <qmsgbox.h>
#include "menu.h"

//
// Definitionen
//

QApplication *a;


char *Datei_Lesen(const char *DName, int ZLaenge)
    {
      char *PUText=NULL;

      FILE *Datei;
      int i=0, linel=0;

      if ( (Datei=fopen(DName,"r")) != 0)
      { 
        while ( !feof(Datei) )
         { 
	  if (PUText == NULL) PUText = (char *)malloc (sizeof(char));
	  else PUText = (char *)realloc (PUText, sizeof(char)*i +1);
	  PUText[i]=fgetc(Datei);
          if (PUText[i]=='\n') linel=0; else linel++;
	  if (linel==ZLaenge)
             {
	      PUText = (char *)realloc (PUText, sizeof(char)*i +1);	      
	      PUText[++i]='\n';
	      linel=0;
             };
	  i++;
         } 

        if (PUText == NULL) PUText = (char *)malloc (sizeof(char));
        else PUText = (char *)realloc (PUText, sizeof(char)*i +1);
        PUText[i]=0;
        fclose(Datei);

        char befehl[50];
        sprintf(befehl,"rm -f %s",DName);
        system(befehl);


      }    
      else
      { 
         printf("Dateifehler!\n");
      };
      return PUText;
 }




//
// Klassen und ihre Definitionen
//

MyWidget::MyWidget( int pzahl, char **param, QWidget *parent=0, const char *name=0 )
        : QWidget( parent, name )
{
   
      if (pzahl==4)
       { 
        DateiName = (char *)malloc(((strlen(param[1])+1)*(sizeof(char))));
        sprintf(DateiName,param[1]);
        DateiName[strlen(param[1])]=0;

        Absender  = (char *)malloc(((strlen(param[2])+1)*(sizeof(char))));
        sprintf(Absender,param[2]);
        Absender[strlen(param[2])]=0;
  
        Empfaenger   = (char *)malloc(((strlen(param[3])+1)*(sizeof(char))));
        sprintf(Empfaenger,param[3]);
        Empfaenger[strlen(param[3])]=0;
       }
      else
       {
        DateiName = (char *)malloc(1*(sizeof(char)));
        DateiName[0]=0;
        Absender  = (char *)malloc(1*(sizeof(char)));
        Absender[0]=0;
        Empfaenger = (char *)malloc(1*(sizeof(char))); 
        Empfaenger[0]=0;
       };
      setMinimumSize( 290, 270 );
      setMaximumSize( 290, 270);
    
      quit = new QPushButton( "Quit", this, "quit" );
      quit->setGeometry( 20, 10, 75, 30 );
      quit->setFont( QFont( "Times", 18, QFont::Bold ) );
      connect( quit, SIGNAL(clicked()), qApp, SLOT(quit()) );
 //     connect( quit, SIGNAL(pressed()), qApp, SLOT(quit()) );

      Return = new QPushButton( "Antworten", this, "antworten" );
      Return->setGeometry( 107, 10, 75, 30 );
      Return->setFont( QFont( "Times", 18, QFont::Bold ) );
      connect( Return, SIGNAL( clicked() ), this, SLOT( answer() ) );
 //     connect( Return, SIGNAL( pressed() ), this, SLOT( answer() ) );

      NeuPU = new QPushButton( "Neues PU", this, "neues PU" );
      NeuPU->setGeometry( 194, 10, 75, 30 );
      NeuPU->setFont( QFont( "Times", 18, QFont::Bold ) );
      connect( NeuPU, SIGNAL(clicked()), this, SLOT( neuespu() ) );
 //     connect( NeuPU, SIGNAL(pressed()), this, SLOT( neuespu() ) );

      Kom_Header = new QLabel("Nachricht von: ",this);
      Kom_Header->setGeometry(22,53,98,20);
      Kom_Header->setAlignment( AlignTop | AlignLeft );

      Header = new QLabel(Absender,this);
      Header->setGeometry(120, 50,150,20);
      Header->setFrameStyle( QFrame::Panel | QFrame::Sunken );
      Header->setAlignment( AlignTop | AlignLeft );

      Kom_Empf =   new QLabel("           an: ",this);
      Kom_Empf->setGeometry(22,78,98,20);
      Kom_Empf->setAlignment( AlignTop | AlignLeft );

      Empf = new QLabel(Empfaenger,this);
      Empf->setGeometry(120, 75, 150,20);
      Empf->setFrameStyle( QFrame::Panel | QFrame::Sunken );
      Empf->setAlignment( AlignTop | AlignLeft );

      if (strlen(DateiName)!=0)
        {
         PUText = new QLabel( Datei_Lesen( DateiName ,41) ,this); 
        }
        else
        {
        PUText = new QLabel( "",this);
        };

      PUText->setGeometry(20,100,250,150);
      PUText->setFrameStyle( QFrame::Panel | QFrame::Sunken );
      PUText->setAlignment( AlignTop | AlignLeft );
}

void MyWidget::answer()
{
  Antwort *ant;
  ant = new Antwort (this, "Blabla");
  ant->resize( 280, 220 );
  ant->setCaption( "Antworten!" );
  if (strlen(Absender)==0) 
      {
      ant->empf->insertItem(" localhost",-1);
      }
      else
      {
      ant->empf->insertItem(Absender,-1);
      };
  ant->readbrowselist();
  ant->exec();
}

void MyWidget::neuespu()
{
  Antwort *ant;
  ant = new Antwort (this, "Blabla");
  ant->resize( 280, 220 );
  ant->empf->insertItem(" localhost",-1);
  ant->readbrowselist();
  ant->setCaption( "Neues PopUP!" );
  ant->empf->setCurrentItem(0);
  ant->exec();
}


Antwort::Antwort( QWidget *parent, const char *name )
        : QDialog( parent, name, TRUE )
{
     ok = new QPushButton( "OK", this );
     ok->setGeometry( 25, 190, 60, 25 );
     connect( ok, SIGNAL(clicked()), SLOT(schicken()));
//     connect( ok, SIGNAL(pressed()), SLOT(schicken()));

     cancel = new QPushButton( "Cancel", this );
     cancel->setGeometry( 195, 190, 60,25 );
     connect( cancel, SIGNAL(clicked()), SLOT(reject()) );
//     connect( cancel, SIGNAL(pressed()), SLOT(reject()) );

     kom_user = new QLabel("Von: ",this);
     kom_user->setGeometry(20,9,30,20);
     user = new QLineEdit( this, "read-write combo" );
     user->setGeometry(55,8,205,22);
     readhostname();
     user->setMaxLength(25);

     kom_empf = new QLabel("An: ",this);
     kom_empf->setGeometry(20,34,30,20);
     empf = new QComboBox( TRUE, this, "read-write combo" );
     empf->setGeometry(55,34,205,26);

     kom_ptext = new QLabel("Text: ",this);
     kom_ptext->setGeometry(20,61,98,20);
     ptext = new QMultiLineEdit(this);
     ptext->setGeometry(20,85,240,100);

}


void Antwort::schicken()
{
   FILE *Datei;
   char *befehlszeile;
   int count=0;
   befehlszeile = (char *)malloc(182*(sizeof(char)));
   Datei=fopen("/tmp/new.pup","w+");

   while (count < ptext->numLines())  
    { 
     fprintf(Datei,"%s\n",ptext->textLine(count)); 
     count++; 
    }
   fclose(Datei);
   sprintf(befehlszeile, "csh -c '%s/smbclient -M %s -U %s < /tmp/new.pup'",SMBPFAD,empf->currentText(),user->text());
   if (system( befehlszeile )==0)
           { 
             QMessageBox *Super;
             Super = new QMessageBox();
             Super->information(this,"                      :-))    " ,"Erfolgreich gesendet!");  
             reject();
              }
   else
           {
             QMessageBox *Fehler;
             Fehler = new QMessageBox();
             Fehler->information(this,"                          ERROR" ,"Fehler bei Schicken!");  
           };
   system("rm -f /tmp/new.pup");
}


void Antwort::readbrowselist()
{
    QFile *Datei;
    char *Zeile;
    int flag1=0,flag2=0;
    Zeile = (char *)malloc(201*(sizeof(char)));
    Datei = new QFile("/tmp/browse.pup");

    if (Datei->open( IO_ReadOnly ))
    {
      while (!(Datei->atEnd()))
      {
        Datei->readLine(Zeile,200);
        if ((strlen(Zeile)==1)&&(flag1==1)) flag2=1;

        if ((flag1==1)&&(flag2==0))
          {
           if ((strlen(Zeile) >22)&&(Zeile[0]=='\t')&&(strncmp(Zeile,"	---",4)==1))
            {
             Zeile[0]=' ';
             Zeile[22]=0;
             empf->insertItem(Zeile,-1);
            };
           };
        if ((strncmp(Zeile,"	Server               Comment",24))==0) flag1=1;

       }
      free(Zeile);
      Datei->close();
    };
}

void Antwort::readhostname()
{
    QFile *Datei;
    char *Zeile;
    Zeile = (char *)malloc(201*(sizeof(char)));
    Datei = new QFile("/etc/HOSTNAME");

    if (Datei->open( IO_ReadOnly ))
      {
        Datei->readLine(Zeile,200);
        user->setText(Zeile);
        Datei->close();
       }
    else
      {
        user->setText(" BUGS-BUNNY");
      };
      free(Zeile);
  
}

int main( int argc, char **argv )
{
    QApplication a( argc, argv );
    MyWidget w(argc, argv);
    w.setGeometry( 100, 100, 400, 400 );
    a.setMainWidget( &w );
    if (argc!=1) {a.beep();};
    w.setCaption( "   KPopUP !     (c) muecketb" );
    w.show();
    return a.exec();
}
